# {{ template.title }} - PLG Template

{% if template.description %}
{{ template.description }}
{% endif %}

## Template Metadata

- **Framework**: {{ template.framework }}
- **Version**: {{ template.version }}
{% if template.metadata %}
- **Category**: {{ template.metadata.category }}
- **Created**: {{ template.metadata.created_at }}
{% endif %}

## Framework Description

{% if template.metadata and template.metadata.framework_description %}
{{ template.metadata.framework_description }}
{% endif %}

## Usage

{% if template.metadata and template.metadata.usage %}
{{ template.metadata.usage }}
{% endif %}

---

## Lifecycle Stages

{% for lifecycle in template.lifecycles %}
### {{ loop.index }}. {{ lifecycle.name }}: {{ lifecycle.description }}

{% if lifecycle.milestones %}
#### Milestones

{% for milestone in lifecycle.milestones %}
{{ loop.index }}. **{{ milestone.title }}**: {{ milestone.description }}
{% endfor %}
{% endif %}

{% if lifecycle.metrics %}
#### Key Metrics

{% for metric in lifecycle.metrics %}
- **{{ metric.name }}**: {{ metric.howToMeasure }} (Benchmark: {{ metric.healthyBenchmark }})
{% endfor %}
{% endif %}

---

{% endfor %}

## Summary

This template includes **{{ template.lifecycles|length }} lifecycle stages** covering the complete user journey:

{% for lifecycle in template.lifecycles %}
- **{{ lifecycle.name }}** ({{ lifecycle.description }}): {{ lifecycle.milestones|length }} milestones, {{ lifecycle.metrics|length }} metrics
{% endfor %}

---

*PLG template generated by skene-growth.*
